@@ -3,7 +3,7 @@
 Hans Roh
 """
 
-__version__ = "0.8.3.18"
+__version__ = "0.8.4.1"
 
 version_info = tuple (map (lambda x: not x.isdigit () and x or int (x),  __version__.split (".")))
 assert len ([x for  x in version_info [:2] if isinstance (x, int)]) == 2, 'major and minor version should be integer'
@@ -11,20 +11,6 @@ assert len ([x for  x in version_info [:2] if isinstance (x, int)]) == 2, 'major
 from .patches import skitaipatch
 from .Atila import Atila
 
-# Events
-app_starting = "app:starting"
-app_started = "app:started"
-app_restarting = "app:restarting"
-app_restarted = "app:restarted"
-app_mounted = "app:mounted"
-app_unmounting = "app:umounting"
-
-request_failed = "request:failed"
-request_success = "request:success"
-request_tearing_down = "request:teardown"
-request_starting = "request:started"
-request_finished = "request:finished"
-
 def load (target, pref = None):
     from rs4 import importer
     import os, copy
