@@ -8,15 +8,18 @@ import random
 from rs4 import jwt
 from aquests.protocols.http import http_date
 from skitai import wsgiappservice
-from skitai.corequest import tasks
+from skitai.corequest import tasks, corequest, get_cloned_was
 import skitai
 from skitai.exceptions import HTTPError
 import uuid
+from skitai.wastuff.api import APIResponse
+from functools import partial
 
 def generate_otp (serial):
     serial = int (md5 (str (serial).encode ()).hexdigest ()[-8:], 16)
     return md5 (str (round (time.time () - serial, -1)).encode ()).hexdigest ()
 
+
 class WAS (wsgiappservice.WAS):
     # mehiods remap ------------------------------------------------
     def __getattr__ (self, name):
@@ -281,6 +284,50 @@ class WAS (wsgiappservice.WAS):
     def Error (self):
         return HTTPError
 
+    def _insert_cloned_was (self, args, kargs):
+        _was = get_cloned_was (self.ID)
+        if args:
+            args = (_was,) + args
+        else:
+            kargs ['args'] = (_was,) + kargs.get ('args', ())
+        return _was, args, kargs
+
+    def ThreadFuture (self, target, *args, **kargs):
+        _was, args, kargs = self._insert_cloned_was (args, kargs)
+        return self.executors.create_thread (_was.ID, target, *args, **kargs).then ()
+
+    def Map (self, tasks, *keys):
+        def mapped_api (was, tasks, keys, status):
+            results = tasks.fetch ()
+            if tasks.count () == 1 and not isinstance (results, (list, tuple)):
+                results = [results]
+
+            data = {}
+            for idx, key in enumerate (keys):
+                if key is None:
+                    continue
+
+                keydata = results [idx]
+                try:
+                    key, field = key.split ('__')
+                except ValueError:
+                    pass
+                else:
+                    if len (keydata) != 1:
+                        raise was.Error ('409 Conflict')
+                    keydata = keydata [0]
+                    if field:
+                        keydata = keydata [field]
+                data [key] = keydata
+            return was.API (status, data)
+
+        status = "200 OK"
+        if isinstance (tasks, str):
+            status = tasks
+            tasks, keys = keys [0], keys [1:]
+        assert tasks.count () == len (keys), "Count of tasks and keys not nmatch"
+        return tasks.then (partial (mapped_api, keys = keys, status = status))
+
     def File (self, *args, **karg):
         return self.response.File (*args, **karg)
 
